⚡ Day 8: 2.2x FASTER with rayon parallel sorting! From 33ms to 15ms 💪

This commit is contained in:
Russell Champoux committed 2025-12-09 16:04:45 -05:00
1 parent ca302578c9
commit 6ff1349679
4 files changed
+104 -28

No files matched your search

+2 -1
View File
@@ -18,8 +18,9 @@ Solutions for [Advent of Code](https://adventofcode.com/) in [Rust](https://www.
| [Day 5](./src/bin/05.rs) | `196.7µs` | `66.3µs` |
| [Day 6](./src/bin/06.rs) | `109.0µs` | `194.2µs` |
| [Day 7](./src/bin/07.rs) | `270.5µs` | `320.2µs` |
| [Day 8](./src/bin/08.rs) | `16.9ms` | `16.2ms` |
**Total: 6.38ms**
**Total: 39.48ms**
<!--- benchmarking table --->
---